@@ -27,7 +27,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
         learn.save(baseModel)
-        shutil.copy(path+os.sep+'models'+os.sep+'model-'+baseModel+'.pth',outputPath)
+        shutil.copy(path+os.sep+'models'+os.sep+baseModel+'.pth',outputPath)
 
         # supervised method
         plainSupervised(path,pathUnlabelled,learn,confidence)
@@ -46,7 +46,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
         learn2.save(outputPath+os.sep+targetModel)
-        shutil.copy(path+os.sep+'models' + os.sep + 'model-' + targetModel + '.pth', outputPath)
+        shutil.copy(path+os.sep+'models' + os.sep + targetModel + '.pth', outputPath)
         shutil.rmtree(path+'_tmp')
 
 
