@@ -116,7 +116,10 @@ def omniModelData(path, pathUnlabelled,learners,transforms,th):
 def plainSupervised(path,pathUnlabelled,learn,th):
     images=sorted(glob.glob(pathUnlabelled+os.sep+"*"))
     i = path.rfind(os.sep)
-    newPath = path[:i] + "_tmp"
+    if i!=-1:
+        newPath = path[:i] + "_tmp"
+    else:
+        newPath = path + "_tmp"
     shutil.copytree(path, newPath)
     for image in images:
         pn=learn.predict(image)
